Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/owncloud/client.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorHannah von Reth <hannah.vonreth@owncloud.com>2021-09-23 12:42:12 +0300
committerHannah von Reth <vonreth@kde.org>2021-09-28 18:26:47 +0300
commit39b92322059412cde95506ffb7c93fe05fba1782 (patch)
treeb3cdbc860b9cff6a69c66ad047d78f6aa3bf1965 /src/gui/folder.h
parent13bc7d51395f50a8584fa09eb3ae2267d7dbd38e (diff)
Rename Folder::ok() to ::isReady()
Diffstat (limited to 'src/gui/folder.h')
-rw-r--r--src/gui/folder.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/gui/folder.h b/src/gui/folder.h
index 8e798a760..ecd3327a9 100644
--- a/src/gui/folder.h
+++ b/src/gui/folder.h
@@ -183,9 +183,9 @@ public:
bool canSync() const;
/**
* Whether the folder is ok
*/
- bool ok() const;
+ bool isReady() const;
/**
* Returns true if the folder needs sync poll interval wise, and can
@@ -183,9 +183,9 @@ public:
bool canSync() const;
/**
- * Whether the folder is ok
+ * Whether the folder is ready
*/